@@ -1155,7 +1155,7 @@ rb_shell_property_changed_generic_cb (GObject *object,
 	g_object_get (object, pspec->name, &value, NULL);
 	BONOBO_ARG_SET_BOOLEAN (arg, value);
 	shell_notify_pb_changes (shell, pspec->name, arg);
-	/* FIXME: arg should be released somehow */
+	bonobo_arg_release (arg);
 }
 
 static void
@@ -1173,7 +1173,7 @@ rb_shell_entry_changed_cb (GObject *object, GParamSpec *pspec, RBShell *shell)
 	arg = bonobo_arg_new (TC_GNOME_Rhythmbox_SongInfo);
 	arg->_value = (gpointer)song_info;
 	shell_notify_pb_changes (shell, "song", arg);
-	/* FIXME: arg should be released somehow */
+	bonobo_arg_release (arg);
 
 #ifdef WITH_DASHBOARD
 	if (song_info) {
@@ -1874,11 +1874,10 @@ rb_shell_set_duration (RBShell *shell, const char *duration)
 static void
 rb_shell_set_window_title (RBShell *shell, const char *window_title)
 {
-	g_free (shell->priv->cached_title);
-	
 	if (window_title == NULL) {
 		rb_debug ("clearing title");
 
+		g_free (shell->priv->cached_title);
 		shell->priv->cached_title = NULL;
 		
 		gtk_window_set_title (GTK_WINDOW (shell->priv->window),
@@ -1890,9 +1889,9 @@ rb_shell_set_window_title (RBShell *shell, const char *window_title)
 
 		if (shell->priv->cached_title &&
 		    !strcmp (shell->priv->cached_title, window_title)) {
-			shell->priv->cached_title = g_strdup (window_title);
 			return;
 		}
+		g_free (shell->priv->cached_title);
 		shell->priv->cached_title = g_strdup (window_title);
 
 		rb_debug ("setting title to \"%s\"", window_title);
